==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QStyleOptionFocusRect_shell.cpp <==
#include "QStyleOptionFocusRect_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionFocusRect(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionFocusRect")
    QStyleOptionFocusRect *_ptr = reinterpret_cast<QStyleOptionFocusRect *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionFocusRect_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionFocusRect_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionFocusRect_shell) ); }

jmethodID QStyleOptionFocusRect_shell::__shell_javaMethod(int pos) const { return QStyleOptionFocusRect_shell::__shell()->javaMethod(typeid(QStyleOptionFocusRect), pos); }

// emitting (writeShellConstructor)
QStyleOptionFocusRect_shell::QStyleOptionFocusRect_shell()
    : QStyleOptionFocusRect()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect_shell()", QStyleOptionFocusRect_shell::__shell())
    QStyleOptionFocusRect_shell::__shell()->constructed(typeid(QStyleOptionFocusRect));
}

QStyleOptionFocusRect_shell::QStyleOptionFocusRect_shell(const QStyleOptionFocusRect& other0)
    : QStyleOptionFocusRect(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect_shell(const QStyleOptionFocusRect& other0)", QStyleOptionFocusRect_shell::__shell())
    QStyleOptionFocusRect_shell::__shell()->constructed(typeid(QStyleOptionFocusRect));
}

// emitting (writeShellDestructor)
QStyleOptionFocusRect_shell::~QStyleOptionFocusRect_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionFocusRect::~QStyleOptionFocusRect()", QStyleOptionFocusRect_shell::__shell())
    QStyleOptionFocusRect_shell::__shell()->destructed(typeid(QStyleOptionFocusRect));
}

void QStyleOptionFocusRect_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionFocusRect_shell*>(ptr)->QStyleOptionFocusRect_shell::__shell()->tryDeleteShell(typeid(QStyleOptionFocusRect));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionFocusRect()
void __qt_construct_QStyleOptionFocusRect_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionFocusRect()")
    Q_UNUSED(__java_arguments)
    QStyleOptionFocusRect *__qt_this = new(__qtjambi_ptr) QStyleOptionFocusRect_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QStyleOptionFocusRect(QStyleOptionFocusRect)
void __qt_construct_QStyleOptionFocusRect_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionFocusRect(QStyleOptionFocusRect)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionFocusRect& __qt_other0 = qtjambi_cast<const QStyleOptionFocusRect& >(__jni_env, other0);
    QStyleOptionFocusRect *__qt_this = new(__qtjambi_ptr) QStyleOptionFocusRect_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QStyleOptionFocusRect_shell
void __qt_destruct_QStyleOptionFocusRect(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionFocusRect")
    reinterpret_cast<QStyleOptionFocusRect_shell*>(ptr)->~QStyleOptionFocusRect_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionFocusRect::QStyleOptionFocusRect()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_initialize_1native__Lio_qt_widgets_QStyleOptionFocusRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionFocusRect_0, sizeof(QStyleOptionFocusRect_shell), typeid(QStyleOptionFocusRect), true, &deleter_QStyleOptionFocusRect, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionFocusRect::QStyleOptionFocusRect(QStyleOptionFocusRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_initialize_1native__Lio_qt_widgets_QStyleOptionFocusRect_2Lio_qt_widgets_QStyleOptionFocusRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect(QStyleOptionFocusRect)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionFocusRect_1, sizeof(QStyleOptionFocusRect_shell), typeid(QStyleOptionFocusRect), true, &deleter_QStyleOptionFocusRect, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QStyleOptionFocusRect::operator=(QStyleOptionFocusRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_assign_1native_1cref_1QStyleOptionFocusRect__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionFocusRect::operator=(QStyleOptionFocusRect)", __qt_this)
        const QStyleOptionFocusRect& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionFocusRect>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_setBackgroundColor_1native_1cref_1QColor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID backgroundColor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor& __qt_backgroundColor0 = QtJambiAPI::valueReferenceFromNativeId<QColor>(backgroundColor0);
        __qt_this->backgroundColor = __qt_backgroundColor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_backgroundColor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor&  __qt_value = __qt_this->backgroundColor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionFocusRect(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionFocusRect>("QStyleOptionFocusRect", "io/qt/widgets/QStyleOptionFocusRect");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleOptionFocusRect, {
        ConstructorInfo(&__qt_construct_QStyleOptionFocusRect_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionFocusRect_1, "Lio/qt/widgets/QStyleOptionFocusRect;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionFocusRect);
    registerMetaType<QStyleOptionFocusRect>("QStyleOptionFocusRect");
    registerSizeOfShell(typeId, sizeof(QStyleOptionFocusRect_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionFocusRect::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QStyleOptionFocusRect_shell.cpp <==
#include "QStyleOptionFocusRect_shell.h"
#include <QtJambi/Cast>

void deleter_QStyleOptionFocusRect(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleOptionFocusRect")
    QStyleOptionFocusRect *_ptr = reinterpret_cast<QStyleOptionFocusRect *>(ptr);
    if(isShell){
        delete static_cast<QStyleOptionFocusRect_shell*>(_ptr);
    }else{
        QtJambiAPI::registerNonShellDeletion(ptr);
        delete _ptr;
    }
}

QtJambiShell* QStyleOptionFocusRect_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QStyleOptionFocusRect_shell) ); }

// emitting (writeShellDestructor)
QStyleOptionFocusRect_shell::~QStyleOptionFocusRect_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QStyleOptionFocusRect::~QStyleOptionFocusRect()", this)
    QStyleOptionFocusRect_shell::__shell()->destructed(typeid(QStyleOptionFocusRect));
}

// emitting (writeShellConstructor)
QStyleOptionFocusRect_shell::QStyleOptionFocusRect_shell()
    : QStyleOptionFocusRect()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect_shell()", this)
    QStyleOptionFocusRect_shell::__shell()->constructed(typeid(QStyleOptionFocusRect));
}

QStyleOptionFocusRect_shell::QStyleOptionFocusRect_shell(const QStyleOptionFocusRect& other0)
    : QStyleOptionFocusRect(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect_shell(const QStyleOptionFocusRect& other0)", this)
    QStyleOptionFocusRect_shell::__shell()->constructed(typeid(QStyleOptionFocusRect));
}

void QStyleOptionFocusRect_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QStyleOptionFocusRect_shell*>(ptr)->QStyleOptionFocusRect_shell::__shell()->tryDeleteShell(typeid(QStyleOptionFocusRect));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QStyleOptionFocusRect()
void __qt_construct_QStyleOptionFocusRect(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionFocusRect()")
    Q_UNUSED(__java_arguments)
    QStyleOptionFocusRect *__qt_this = new(__qtjambi_ptr) QStyleOptionFocusRect_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleOptionFocusRect::QStyleOptionFocusRect()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_initialize_1native__Lio_qt_widgets_QStyleOptionFocusRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionFocusRect, sizeof(QStyleOptionFocusRect_shell), typeid(QStyleOptionFocusRect), 0, true, &deleter_QStyleOptionFocusRect, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QStyleOptionFocusRect(QStyleOptionFocusRect)
void __qt_construct_QStyleOptionFocusRect_cref_QStyleOptionFocusRect(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleOptionFocusRect(QStyleOptionFocusRect)")
    jobject other0 = __java_arguments[0].l;
    const QStyleOptionFocusRect& __qt_other0 = qtjambi_cast<const QStyleOptionFocusRect&>(__jni_env, other0);
    QStyleOptionFocusRect *__qt_this = new(__qtjambi_ptr) QStyleOptionFocusRect_shell(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QStyleOptionFocusRect::QStyleOptionFocusRect(QStyleOptionFocusRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_initialize_1native__Lio_qt_widgets_QStyleOptionFocusRect_2Lio_qt_widgets_QStyleOptionFocusRect_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleOptionFocusRect::QStyleOptionFocusRect(QStyleOptionFocusRect)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleOptionFocusRect_cref_QStyleOptionFocusRect, sizeof(QStyleOptionFocusRect_shell), typeid(QStyleOptionFocusRect), 0, true, &deleter_QStyleOptionFocusRect, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleOptionFocusRect_shell
void __qt_destruct_QStyleOptionFocusRect(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleOptionFocusRect")
    reinterpret_cast<QStyleOptionFocusRect_shell*>(ptr)->~QStyleOptionFocusRect_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleOptionFocusRect::operator=(QStyleOptionFocusRect)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_assign_1native_1cref_1QStyleOptionFocusRect__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QStyleOptionFocusRect::operator=(QStyleOptionFocusRect)", __this_nativeId)
        const QStyleOptionFocusRect& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QStyleOptionFocusRect>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_setBackgroundColor_1native_1cref_1QColor__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID backgroundColor0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor& __qt_backgroundColor0 = QtJambiAPI::valueReferenceFromNativeId<QColor>(backgroundColor0);
        __qt_this->backgroundColor = __qt_backgroundColor0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_backgroundColor_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QColor&  __qt_value = __qt_this->backgroundColor;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleOptionFocusRect_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleOptionFocusRect *__qt_this = QtJambiAPI::objectFromNativeId<QStyleOptionFocusRect>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleOptionFocusRect(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleOptionFocusRect>("QStyleOptionFocusRect", "io/qt/widgets/QStyleOptionFocusRect");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleOptionFocusRect, {
        ConstructorInfo(&__qt_construct_QStyleOptionFocusRect, nullptr)
       ,ConstructorInfo(&__qt_construct_QStyleOptionFocusRect_cref_QStyleOptionFocusRect, "Lio/qt/widgets/QStyleOptionFocusRect;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleOptionFocusRect);
    registerMetaType<QStyleOptionFocusRect>("QStyleOptionFocusRect");
    registerSizeOfShell(typeId, sizeof(QStyleOptionFocusRect_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QStyleOption), typeId, [](void *ptr, qintptr& offset) -> bool {
            QStyleOption *object = reinterpret_cast<QStyleOption *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = object->type == QStyleOptionFocusRect::Type;
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
